boto v2.26.0
============

:date: 2014/02/27

This release adds support for MFA tokens in the AWS STS ``assume_role`` & the
introduction of the ``boto.rds2`` module (which has full support for the entire
RDS API). It also includes the addition of request hooks & many bugfixes.


Changes
-------

* Added support for MFA in STS AssumeRole. (:sha:`899810c`)
* Fixed how DynamoDB v2 works with Global Secondary Indexes. (:issue:`2122`,
  :sha:`f602c95`)
* Add request hooks and request logger. (:issue:`2125`, :sha:`e8b20fe`)
* Don't pull the security token from the environment or config when a caller
  supplies the access key and secret. (:issue:`2123`, :sha:`4df1694`)
* Read EvaluateTargetHealth from Route53 resource record set. (:issue:`2120`,
  :sha:`0a97158`)
* Prevent implicit string decode in hmac-v4 handlers. (:issue:`2037`,
  :issue:`2033`, :sha:`8e56a5f`)
* Updated Datapipeline to include all current regions. (:issue:`2121`,
  :sha:`dff5e3e`)
* Bug fix for Google Storage generate_url authentication. (:issue:`2116`,
  :issue:`2108`, :sha:`5a50932`)
* Handle JSON error responses in BotoServerError. (:issue:`2113`, :issue:`2077`,
  :sha:`221085e`)
* Corrected a typo in SQS tutorial. (:issue:`2114`, :sha:`7ed41f7`)
* Add CloudFormation template capabilities support. (:issue:`2111`,
  :issue:`2075`, :sha:`65a4323`)
* Add SWF layer1_decisions to docs. (:issue:`2110`, :issue:`2062`,
  :sha:`6039cc9`)
* Add support for request intervals in health checks. (:issue:`2109`,
  :sha:`660b01a`)
* Added checks for invalid regions to the ``bin`` scripts (:issue:`2107`,
  :sha:`bbb9f1e`)
* Better error output for unknown region - (:issue:`2041`, :issue:`1983`,
  :sha:`cd63f92`)
* Added certificate tests for CloudTrail. (:issue:`2106`, :sha:`a7e9b4c`)
* Updated Kinesis endpoints. (:sha:`7bd4b6e`)
* Finished implementation of RDS's DescribeDBLogFiles. (:issue:`2084`,
  :sha:`f3c706c`)
* Added support for RDS log file downloading. (:issue:`2086`, :issue:`1993`,
  :sha:`4c51841`)
* Added some unit tests for CloudFront. (:issue:`2076`, :sha:`6c46b1d`)
* GS should ignore restore_headers as they are never set. (:issue:`2067`,
  :sha:`f02aeb3`)
* Update CloudFormation to support the latest API. (:issue:`2101`,
  :sha:`ea1b1b6`)
* Added Route53 health checks. (:issue:`2054`, :sha:`9028f7d`)
* Merge branch 'rds2' into develop Fixes #2097. (:issue:`2097`, :sha:`6843c16`)
* Fix Param class convert method (:issue:`2094`, :sha:`5cd4598`)
* Added support for Route53 aliasing. (:issue:`2096`, :sha:`df5fa40`)
* Removed the dependence on ``example.com`` within the Route53 tests.
  (:issue:`2098`, :sha:`6ce9e0f`)
* Fixed ``has_item`` support in DynamoDB v2. (:issue:`2090`, :sha:`aada5d3`)
* Fix a little typo bug in the S3 tutorial. (:issue:`2088`, :sha:`c091d27`)
